Crate defmt_decoder[−][src]
This is supported on
unstable only.Expand description
Modules
| log | This module provides interoperability utilities between |
Structs
| Frame | A log frame |
| Location | Location of a defmt log statement in the elf-file |
| StringEntry | A format string and it’s |
| Table | Internal table that holds log levels and maps format strings to indices |
| TableEntry | Entry in |
Enums
| DecodeError | |
| Tag | Specifies the origin of a format string |
Constants
| DEFMT_VERSION | Supported |
Type Definitions
| Locations | Mapping of memory address to |