Module defmt_decoder::log

source ·
Available on unstable only.
This module provides interoperability utilities between defmt and the log crate.

If you are implementing a custom defmt decoding tool, this module can make it easier to integrate it with logs produced with the log crate.

Structs

A log record representing a defmt log frame.

Functions

Initializes a log sink that handles defmt frames.
Determines whether metadata belongs to a log record produced by log_defmt.
Logs a defmt frame using the log facade.