Function defmt_decoder::log::is_defmt_frame
source · [−]Available on
unstable only.Expand description
Determines whether metadata belongs to a log record produced by log_defmt.
unstable only.Determines whether metadata belongs to a log record produced by log_defmt.