Struct defmt_decoder::log::Printer [−][src]
pub struct Printer<'a> { /* fields omitted */ }This is supported on
unstable only.Expand description
Printer for DefmtRecords.
Implementations
Configure whether to include location info (file, line) in the output.
If true, an additional line will be included in the output that contains file and line
information of the logging statement.
By default, this is false.
Pads the defmt timestamp to take up at least the given number of characters.