Struct defmt_decoder::Frame [−][src]
pub struct Frame<'t> { /* fields omitted */ }This is supported on
unstable only.Expand description
A log frame
Implementations
impl<'t> Frame<'t>[src]
impl<'t> Frame<'t>[src]pub fn display(&'t self, colored: bool) -> DisplayFrame<'t>[src]
pub fn display(&'t self, colored: bool) -> DisplayFrame<'t>[src]Returns a struct that will format this log frame (including message, timestamp, level, etc.).
pub fn display_timestamp(&'t self) -> Option<DisplayMessage<'t>>[src]
pub fn display_message(&'t self) -> DisplayMessage<'t>[src]
pub fn display_message(&'t self) -> DisplayMessage<'t>[src]Returns a struct that will format the message contained in this log frame.