Struct defmt_decoder::Table [−][src]
pub struct Table { /* fields omitted */ }This is supported on
unstable only.Expand description
Internal table that holds log levels and maps format strings to indices
Implementations
impl Table[src]
impl Table[src]pub fn new(entries: BTreeMap<usize, TableEntry>) -> Self[src]
pub fn new(entries: BTreeMap<usize, TableEntry>) -> Self[src]NOTE caller must verify that defmt symbols are compatible with this version of the decoder crate using the check_version function
pub fn parse(elf: &[u8]) -> Result<Option<Table>, Error>[src]
pub fn parse(elf: &[u8]) -> Result<Option<Table>, Error>[src]Parses an ELF file and returns the decoded defmt table.
This function returns None if the ELF file contains no .defmt section.
pub fn parse_ignore_version(elf: &[u8]) -> Result<Option<Table>, Error>[src]
pub fn parse_ignore_version(elf: &[u8]) -> Result<Option<Table>, Error>[src]Like parse, but does not verify that the defmt version in the firmware matches the host.
CAUTION: This is meant for defmt/probe-run development only and can result in reading garbage data.
pub fn set_timestamp_entry(&mut self, timestamp: TableEntry)[src]
pub fn indices(&self) -> impl Iterator<Item = usize> + '_[src]
pub fn is_empty(&self) -> bool[src]
pub fn raw_symbols(&self) -> impl Iterator<Item = &str> + '_[src]
pub fn raw_symbols(&self) -> impl Iterator<Item = &str> + '_[src]Iterates over the raw symbols of the table entries