Crate defmt_decoder[−][src]
This is supported on
unstable only.Decodes defmt log frames
NOTE: The decoder always runs on the host!
This is an implementation detail of probe-run and
not meant to be consumed by other tools at the moment so all the API is unstable.
Modules
| log | This module provides interoperability utilities between |
Structs
| StringEntry | |
| Table | Internal table that holds log levels and maps format strings to indices |
| TableEntry |
Enums
| DecodeError | |
| Tag |
Constants
| DEFMT_VERSION | Supported |