Module defmt_decoder::log [−][src]
This is supported on
unstable only.This module provides interoperability utilities between defmt and the log crate.
If you are implementing a custom defmt decoding tool, this module can make it easier to
integrate it with logs produced with the log crate.
Structs
| DefmtRecord | A |
| Printer | Printer for |
Functions
| init_logger | Initializes a |
| is_defmt_frame | Determines whether |
| log_defmt | Logs a defmt frame using the |