Struct defmt_decoder::log::Printer[][src]

pub struct Printer<'a> { /* fields omitted */ }
This is supported on unstable only.
Printer for DefmtRecords.

Implementations

impl<'a> Printer<'a>[src]

pub fn include_location(&mut self, include_location: bool) -> &mut Self[src]

Configure whether to include location info (file, line) in the output.

If true, an additional line will be included in the output that contains file and line information of the logging statement. By default, this is false.

pub fn min_timestamp_width(&mut self, min_timestamp_width: usize) -> &mut Self[src]

Pads the defmt timestamp to take up at least the given number of characters.

pub fn print_colored<W: Write>(&self, sink: &mut W) -> Result<()>[src]

Prints the colored log frame to sink.

The format is as follows (this is not part of the stable API and may change):

<timestamp> <level> <args>
└─ <module> @ <file>:<line>